@@ -1,4 +1,9 @@
 class Options(object):
+    """
+    This generates an informative object on the #::unrest.UnRest instance used
+    as reply for http OPTIONS request on the unrest API index.
+    """
+
     def __init__(self, unrest):
         self.unrest = unrest
 
@@ -16,7 +21,7 @@ class Options(object):
 
     def get_properties(self, rest):
         return {
-            property.name: self.get_property(property.sqlalchemy_type)
+            property.name: self.get_property(property.type)
             for property in rest.properties
         }
 
@@ -39,7 +44,7 @@ class Options(object):
             'properties': self.get_properties(rest),
             'relationships': self.get_relationships(rest),
             'methods': rest.methods,
-            'batch': rest.allow_batch
+            'batch': rest.allow_batch,
         }
 
     def all(self):
